|
|
|
|
| Synopsis |
|
|
|
| Documentation |
|
|
|
|
Instances | |
|
|
|
| Run an EventT wrapped action. This is a "raw" action - there is no
interaction with the state (including event graph) except whatever the
action itself does.
|
|
|
| Initialize the event queue and other stuff, run the provided "start
event", and run the queue until it's empty or until the simulation is
paused.
|
|
|
| Repeatedly pull and run the next event in the queue until it's
empty or until the simulation is paused using pauseSimulation
or something equivalent.
|
|
| newEventIOState :: Ord t => t -> IO (EventIOState t) | Source |
|
|
|
|
|
|
|
|
|
|
|
|
|
| Add an event handler to be called when the specified event happens.
|
|
|
| Remove an event handler given its ID, and return it if it was in the set.
|
|
| Produced by Haddock version 2.4.2 |